#!/usr/bin/env node
var jscpd = require('jscpd');
var nunjucks = require('nunjucks');
var fs = require('fs');
var program = require('commander');
var decodeUtil = require('./decode_util');

program
 .arguments('<output>')
 .option('-p, --path <path>', 'folder to start scan')
 .option('-f, --files <files>', 'glob pattern for find code')
 .option('-l, --language <language>', 'language to scan (html,css,js)')
 .option('-c, --channel <channel>', 'slack channel post into')
 .action(function(output) {
   scanCode(output);
 })
 .parse(process.argv);

function scanCode(output){
    console.log('path: %s channel: %s file: %s languages: %s output: %s',
       program.path, program.channel,program.files,program.languages, output);
    
    var options = {
      reporter:'json'
    };

    if(program.path) options.path = program.path;
    if(program.files) options.files = program.files;
    // if(program.languages) options.languages = program.languages;
    // if(program.output) options.output = program.output;

    var instance = new jscpd();
    var result = instance.run(options);
    nunjucks.configure(__dirname);
    var outputhtml = nunjucks.render('html.html', { lang:program.language, duplicates: formatCodeInResult(result.report.duplicates) });
    fs.writeFile(output, outputhtml, function(err) {
        if(err) {
            return console.log(err);
        }

        console.log("The file was saved!");
    }); 
}

function formatCodeInResult(result){
    for(var i=0;i<result.length;i++){
        result[i].fragment = decodeUtil.htmlDecode(result[i].fragment);
    }
    return result;
}